@@ -1,4 +1,4 @@
 class MatchBase:
     def __init__(self, context: object, match_id: str) -> None:
-        self.context = context
+        self._context = context
         self.match_id = match_id
